# yooink

A Python package to access Ocean Observatories Initiative (OOI) data via 
the m2m (machine to machine) interface. 

## Documentation

For more information about how to install and use yooink, check out the 
documentation site: *Coming soon!*

## Development

This project is still in early development. To access and work on it, clone 
this repository. In a terminal window, navigate to the same folder where 
the pyproject.toml is located, and enter the following command:

```bash
pip install -e .
```

*note: The dot at the end is important!*
